# bokeh_wordcloud2
a (mostly complete) bokeh implementation of [wordcloud2-js](https://wordcloud2-js.timdream.org)

This extension attempts to make wordcloud available inside the bokeh ecosystem

This was made as part of a learning project to make bokeh widgets, but it was too good not to share.

## Installation

`pip install git+https://github.com/joranbeasley/bokeh_wordcloud2.git`

or you can clone this repo and run `setup.py install` or `pip install <git_checkout_directory>`
## Documentation
## [>>> |Read The Docs| <<<](https://bokeh-wordcloud2.readthedocs.io/en/latest/getting_started.html)

and try the [interactive jupyer notebook](https://gke.mybinder.org/v2/gh/joranbeasley/bokeh-wordcloud-notebook/master?filepath=bokeh_wordcloud2.ipynb)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/joranbeasley/master?filepath=bokeh_wordcloud2.ipynb)

and check out the [examples](/examples)
